langmuir_model: Langmuir Isotherm Model

View source: R/Isotherms.R

langmuir_modelR Documentation

Langmuir Isotherm Model

Description

Langmuir isotherm assumes monolayer adsorption onto a surface with a finite number of identical sites (Langmuir, 1918). It is characterized by uniform energies of adsorption onto the surface and no transmigration of adsorbate in the plane of the surface. The model is described by the equation: Q = (Qmax * KL * Ce) / (1 + KL * Ce) where Q is the amount adsorbed, Ce is the equilibrium concentration, Qmax is the maximum adsorption capacity, and KL is the Langmuir constant. https://doi.org/10.1021/ja02242a004

Usage

langmuir_model(Ce, Qe)

Arguments

Ce

Numeric vector of equilibrium concentrations.

Qe

Numeric vector of amount adsorbed.

Value

A named list of Langmuir parameters and model details.

See Also

Other linear: bet_model(), freundlich_model(), temkin_model()

Examples

Ce <- c(1, 2, 3, 4, 5)
Qe <- c(0.8, 1.5, 2.1, 2.6, 2.9)
result <- langmuir_model(Ce, Qe)
print(result[1:2])
print(result$`Model Summary`)
print(result$Plot)

AdsorpR documentation built on Sept. 2, 2026, 5:06 p.m.