temkin_model: Temkin Isotherm Model

View source: R/Isotherms.R

temkin_modelR Documentation

Temkin Isotherm Model

Description

The Temkin isotherm considers the effects of indirect adsorbate/adsorbate interactions. It assumes that the heat of adsorption of all molecules in the layer decreases linearly with coverage (Temkin and Pyzhev 1940). The model is given by: Q = (RT / bT) * ln(AT * Ce)

Usage

temkin_model(Ce, Qe, R = 8.314, T = 298)

Arguments

Ce

Numeric vector of equilibrium concentrations.

Qe

Numeric vector of amount adsorbed.

R

Universal gas constant.

T

Temperature in Kelvin.

Value

A named list of Temkin parameters and model details.

See Also

Other linear: bet_model(), freundlich_model(), langmuir_model()

Examples

Ce <- c(1, 2, 3, 4, 5)
Qe <- c(0.8, 1.5, 2.1, 2.6, 2.9)
result <- temkin_model(Ce, Qe)
print(result[1:2])
print(result$`Model Summary`)
print(result$Plot)

AdsorpR documentation built on Sept. 2, 2026, 5:06 p.m.