| bet_model | R Documentation |
The BET isotherm extends the Langmuir theory to multilayer adsorption (Brunauer et al., 1938). It is used to estimate surface area and porosity of adsorbents. The model is applicable under specific physical or chemical conditions and is given by: Q = (Qm * Cb * P) / ((P0 - P)(1 + (Cb - 1) * P / P0)) https://doi.org/10.1021/ja01269a023
bet_model(Ce, Qe, Cs = max(Ce) * 1.1)
Ce |
Numeric vector of equilibrium concentrations. |
Qe |
Numeric vector of amount adsorbed. |
Cs |
Saturation concentration. |
A named list of BET parameters and model details.
Other linear:
freundlich_model(),
langmuir_model(),
temkin_model()
Ce <- c(1, 2, 3, 4, 5)
Qe <- c(0.8, 1.5, 2.1, 2.6, 2.9)
result <- bet_model(Ce, Qe)
print(result[1:2])
print(result$`Model Summary`)
print(result$Plot)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.