| freundlich_model | R Documentation |
Freundlich isotherm describes adsorption on heterogeneous surfaces and assumes that the stronger binding sites are occupied first (Freundlich, 1907). It is represented by: Q = Kf * Ce^(1/n) where Kf is the Freundlich constant related to adsorption capacity and n indicates adsorption intensity. https://doi.org/10.1002/ange.19070201805
freundlich_model(Ce, Qe)
Ce |
Numeric vector of equilibrium concentrations. |
Qe |
Numeric vector of amount adsorbed. |
A named list of Freundlich parameters and model details.
Other linear:
bet_model(),
langmuir_model(),
temkin_model()
Ce <- c(1, 2, 3, 4, 5)
Qe <- c(0.8, 1.5, 2.1, 2.6, 2.9)
result <- freundlich_model(Ce, Qe)
print(result[1:2])
print(result$`Model Summary`)
print(result$Plot)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.