| temkin_model | R Documentation |
The Temkin isotherm considers the effects of indirect adsorbate/adsorbate interactions. It assumes that the heat of adsorption of all molecules in the layer decreases linearly with coverage (Temkin and Pyzhev 1940). The model is given by: Q = (RT / bT) * ln(AT * Ce)
temkin_model(Ce, Qe, R = 8.314, T = 298)
Ce |
Numeric vector of equilibrium concentrations. |
Qe |
Numeric vector of amount adsorbed. |
R |
Universal gas constant. |
T |
Temperature in Kelvin. |
A named list of Temkin parameters and model details.
Other linear:
bet_model(),
freundlich_model(),
langmuir_model()
Ce <- c(1, 2, 3, 4, 5)
Qe <- c(0.8, 1.5, 2.1, 2.6, 2.9)
result <- temkin_model(Ce, Qe)
print(result[1:2])
print(result$`Model Summary`)
print(result$Plot)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.